@@ -104,7 +104,7 @@ def main(argv):
     parser.add_argument(
         "--mode",
         default=None,
-        help=f"Use a specific mode. Available modes are {AxisMode.values()}",
+        help=f"Use a specific mode. Available modes are {[item.value for item in AxisMode]}",
     )
     parser.add_argument(
         "--full-image",
