@@ -179,8 +179,8 @@ def main(argv):
 
     scan = ScanFactory.create_scan_object(options.scan_path, entry=options.entry)
 
-    dark_method = ReduceMethod.from_value(options.dark_method)
-    flat_method = ReduceMethod.from_value(options.flat_method)
+    dark_method = ReduceMethod(options.dark_method)
+    flat_method = ReduceMethod(options.flat_method)
 
     if options.run:
         exit(
