@@ -1,6 +1,7 @@
 # coding: utf-8
 from __future__ import annotations
 
+from enum import Enum as _Enum
 import getpass
 import logging
 import socket
@@ -10,7 +11,6 @@ from multiprocessing import Process
 
 from jsonrpc import JSONRPCResponseManager, dispatcher
 from psutil import process_iter
-from silx.utils.enum import Enum as _Enum
 from werkzeug.serving import run_simple
 from werkzeug.wrappers import Request, Response
 
@@ -26,12 +26,6 @@ class TangoAcquisitionStatus(_Enum):
     ENDED = "ended"
 
 
-class _TangoState:
-    MOVING = "moving"
-    ON = "on"
-    FAULT = "fault"
-
-
 class BlissAcquisition:
     """Define an acquisition made with bliss / tango"""
 
@@ -59,7 +53,7 @@ class BlissAcquisition:
         self.scan_numbers.append(scan_number)
 
     def set_status(self, status):
-        self.status = TangoAcquisitionStatus.from_value(status)
+        self.status = TangoAcquisitionStatus(status)
 
     def end(self, end_time, succeed: bool, error: str | None):
         if succeed is True:
@@ -257,7 +251,7 @@ def send_signal_to_local_rpc_servers(signal, port: int, extended_find: bool = Tr
                         proc.send_signal(signal)
                         found = True
                         return
-            except (psutil.PermissionError, psutil.AccessDenied):
+            except (PermissionError, psutil.AccessDenied):
                 pass
     if not extended_find:
         return
@@ -272,5 +266,5 @@ def send_signal_to_local_rpc_servers(signal, port: int, extended_find: bool = Tr
                             f"process pid: {proc.pid} - {proc.name()} seems to be one occupying port {port}"
                         )
                         return
-            except (psutil.PermissionError, psutil.AccessDenied):
+            except (PermissionError, psutil.AccessDenied):
                 pass
