@@ -129,6 +129,7 @@ class CastVolumeTask(
 
         # build output volume object
         overwrite = configuration.get("overwrite", False)
+        remove_input_volume = configuration.get("remove_input_volume", False)
         output_volume.overwrite = overwrite
         cratios = configuration.get("compression_ratios", None)
         if cratios is not None:
@@ -161,6 +162,7 @@ class CastVolumeTask(
                     rescale_max_percentile=rescale_max_percentile,
                     save=True,
                     store=False,
+                    remove_input_volume=remove_input_volume,
                 )
             except Exception as e:
                 mess = f"volume cast of {str(input_volume)} failed. Reason is {str(e)}"
@@ -194,7 +196,7 @@ class CastVolumeTask(
                 )
                 if overwrite:
                     command += " --overwrite"
-                command += f" --output_type={str(output_data_type)}"
+                command += f" --output-data-type={str(output_data_type)}"
                 if data_min is not None:
                     command += f" --data_min={data_min}"
                 if data_max is not None:
@@ -203,7 +205,8 @@ class CastVolumeTask(
                     command += f" --rescale_min_percentile={rescale_min_percentile}"
                 if rescale_max_percentile is not None:
                     command += f" --rescale_max_percentile={rescale_max_percentile}"
-
+                if remove_input_volume:
+                    command += " --remove-input-volume"
                 return command
 
             script_name = get_slurm_script_name(prefix="nabu_cast")
