@@ -5,6 +5,7 @@ import functools
 import logging
 import os
 import gc
+from collections.abc import Callable
 from tomwer.io.utils import format_stderr_stdout
 from silx.utils.deprecation import deprecated, deprecated_warning
 from silx.io.utils import open as open_hdf5
@@ -54,7 +55,7 @@ from nabu.pipeline.fullfield.nabu_config import (
     nabu_config as nabu_fullfield_default_config,
 )
 from processview.core.superviseprocess import SuperviseProcess
-from silx.utils.enum import Enum as _Enum
+from enum import Enum as _Enum
 
 from tomwer.core.process.task import Task
 from tomwer.core.scan.edfscan import EDFTomoScan
@@ -85,6 +86,7 @@ def run_slices_reconstruction(
     advancement=None,
     process_id: int | None = None,
     instantiate_classes_only: bool = False,
+    invalid_slice_callback: Callable[[str], None] | None = None,
 ) -> tuple:
     """
     call nabu for a reconstruction on scan with the given configuration
@@ -142,7 +144,9 @@ def run_slices_reconstruction(
     scan.nabu_recons_params = sc_config
 
     # handle special cases like several db...
-    nabu_configurations = interpret_tomwer_configuration(config, scan=scan)
+    nabu_configurations = interpret_tomwer_configuration(
+        config, scan=scan, invalid_slice_callback=invalid_slice_callback
+    )
     output_urls = []
     stderrs = []
     stdouts = []
@@ -227,6 +231,7 @@ class NabuSlicesTask(
     optional_input_names=(
         "dry_run",
         "serialize_output_data",
+        "invalid_slice_callback",
     ),
     output_names=("data", "nabu_params", "future_tomo_obj"),
 ):
@@ -288,6 +293,9 @@ class NabuSlicesTask(
                 dry_run=self._dry_run,
                 process_id=self.process_id,
                 instantiate_classes_only=True,
+                invalid_slice_callback=self.get_input_value(
+                    "invalid_slice_callback", None
+                ),
             )
         except Exception as e:
             mess = f"Fail to instantiate slice reconstructor for {str(scan)}. Reason is {e}."
@@ -425,7 +433,11 @@ class NabuSlicesTask(
             self._current_processing.cancel()
 
 
-def interpret_tomwer_configuration(config: dict, scan: TomwerScanBase | None) -> tuple:
+def interpret_tomwer_configuration(
+    config: dict,
+    scan: TomwerScanBase | None,
+    invalid_slice_callback: Callable[[str], None] | None = None,
+) -> tuple:
     """
     tomwer can 'mock' the nabu reconstruction to request more feature.
     Typical use case is that we can ask for reconstruction of several
@@ -471,9 +483,10 @@ def interpret_tomwer_configuration(config: dict, scan: TomwerScanBase | None) ->
             index_max = index_max - 1
 
             if slice_index > index_max:
-                _logger.error(
-                    f"slice index {slice_index} requested. But slice index must be in 0-{index_max} - ignore this request"
-                )
+                error_message = f"{scan.get_identifier().short_description()}\n\nCannot reconstruct slice {slice_index} along plane {axis.value}. Must be in [0-{index_max}]"
+                _logger.error(error_message)
+                if invalid_slice_callback is not None:
+                    invalid_slice_callback(error_message)
                 return False
             return True
 
@@ -612,7 +625,7 @@ class SingleSliceRunner(_NabuBaseReconstructor):
                 config["reconstruction"]["end_z"] = self.slice_index
             else:
                 raise ValueError(
-                    f"self.axis has an invalid value: {self.axis} when expected to be in {NabuPlane.values()}"
+                    f"self.axis has an invalid value: {self.axis} when expected to be in {[item.value for item in NabuPlane]}"
                 )
 
         if self.slice_index is not None:
@@ -842,7 +855,7 @@ class NabuSliceMode(_Enum):
     def getSlices(slices, scan, axis=NabuPlane.XY) -> tuple:
         res = []
         try:
-            mode = NabuSliceMode.from_value(slices)
+            mode = NabuSliceMode(slices)
         except ValueError:
             try:
                 res = utils.retrieve_lst_of_value_from_str(slices, type_=int)
@@ -850,7 +863,7 @@ class NabuSliceMode(_Enum):
                 pass
         else:
             if mode == mode.MIDDLE:
-                axis = NabuPlane.from_value(axis)
+                axis = NabuPlane(axis)
                 if axis is NabuPlane.XY:
                     n_slice = scan.dim_2 or 2048
                 elif axis in (NabuPlane.YZ, NabuPlane.XZ):
