@@ -10,7 +10,7 @@ from nabu.pipeline.config import generate_nabu_configfile, parse_nabu_config_fil
 from nabu.pipeline.fullfield.nabu_config import (
     nabu_config as nabu_fullfield_default_config,
 )
-from silx.utils.enum import Enum as _Enum
+from enum import Enum
 
 from tomoscan.identifier import VolumeIdentifier
 import tomwer.version
@@ -240,13 +240,13 @@ def get_multi_cor_recons_volume_identifiers(
     return res
 
 
-class _NabuMode(_Enum):
+class _NabuMode(Enum):
     FULL_FIELD = "standard acquisition"
     HALF_ACQ = "half acquisition"
     # HELICAL = "helical acquisition"
 
 
-class _NabuStages(_Enum):
+class _NabuStages(Enum):
     INI = "initialization"
     PRE = "pre-processing"
     PHASE = "phase"
@@ -267,7 +267,7 @@ class _NabuStages(_Enum):
     @staticmethod
     def getProcessEnum(stage):
         """Return the process Enum associated to the stage"""
-        stage = _NabuStages.from_value(stage)
+        stage = _NabuStages(stage)
         if stage is _NabuStages.INI:
             raise NotImplementedError()
         elif stage is _NabuStages.PRE:
@@ -281,7 +281,7 @@ class _NabuStages(_Enum):
         raise NotImplementedError()
 
 
-class _NabuPreprocessing(_Enum):
+class _NabuPreprocessing(Enum):
     """Define all the preprocessing action possible and the order they
     are applied on"""
 
@@ -296,7 +296,7 @@ class _NabuPreprocessing(_Enum):
         )
 
 
-class _NabuPhase(_Enum):
+class _NabuPhase(Enum):
     """Define all the phase action possible and the order they
     are applied on"""
 
@@ -309,7 +309,7 @@ class _NabuPhase(_Enum):
         return (_NabuPhase.PHASE, _NabuPhase.UNSHARP_MASK, _NabuPhase.LOGARITHM)
 
 
-class _NabuProcessing(_Enum):
+class _NabuProcessing(Enum):
     """Define all the processing action possible"""
 
     RECONSTRUCTION = "reconstruction"
@@ -319,7 +319,7 @@ class _NabuProcessing(_Enum):
         return (_NabuProcessing.RECONSTRUCTION,)
 
 
-class _NabuPostProcessing(_Enum):
+class _NabuPostProcessing(Enum):
     """Define all the post processing action available"""
 
     SAVE_DATA = "save"
@@ -329,11 +329,12 @@ class _NabuPostProcessing(_Enum):
         return (_NabuPostProcessing.SAVE_DATA,)
 
 
-class _NabuReconstructionMethods(_Enum):
+class _NabuReconstructionMethods(Enum):
     FBP = "FBP"
+    MLEM = "MLEM"
 
 
-class _NabuPhaseMethod(_Enum):
+class _NabuPhaseMethod(Enum):
     """
     Nabu phase method
     """
@@ -354,10 +355,10 @@ class _NabuPhaseMethod(_Enum):
             elif value.lower() == "ctf":
                 return _NabuPhaseMethod.CTF
         else:
-            return super().from_value(value=value)
+            return _NabuPhaseMethod(value=value)
 
 
-class _NabuFBPFilterType(_Enum):
+class _NabuFBPFilterType(Enum):
     RAMLAK = "ramlak"
     SHEPP_LOGAN = "shepp-logan"
     COSINE = "cosine"
@@ -368,12 +369,12 @@ class _NabuFBPFilterType(_Enum):
     HILBERT = "hilbert"
 
 
-class _NabuPaddingType(_Enum):
+class _NabuPaddingType(Enum):
     ZEROS = "zeros"
     EDGES = "edges"
 
 
-class RingCorrectionMethod(_Enum):
+class RingCorrectionMethod(Enum):
     NONE = "None"
     MUNCH = "munch"
     VO = "vo"
@@ -408,6 +409,9 @@ def nabu_std_err_has_error(errs: bytes | None):
             or " unable to import 'siphash24.siphash13" in line
             or "_create_built_program_from_source_cached" in line
             or "prg.build(options_bytes," in line
+            or (
+                "Performing MLEM" in line and "iterations" in line
+            )  # corrct usage of tqdm (goes to stderr)
         )
 
     if errs is None:
