@@ -1,7 +1,7 @@
 from __future__ import annotations
 import os
 import logging
-from silx.utils.enum import Enum as _Enum
+from enum import Enum as _Enum
 from tomwer.io.utils.raw_and_processed_data import (
     to_processed_data_path,
 )
@@ -30,7 +30,7 @@ class NabuOutputFileFormat(_Enum):
     def from_value(cls, value):
         if isinstance(value, str):
             value = value.lstrip(".")
-        return super().from_value(value)
+        return NabuOutputFileFormat(value)
 
 
 def get_file_format(file_str):
