@@ -430,7 +430,7 @@ class SAAxisTask(
             params.image_width = scan.dim_1
         scan.saaxis_params = params
 
-        mode = ReconstructionMode.from_value(params.mode)
+        mode = ReconstructionMode(params.mode)
         if mode is not ReconstructionMode.VERTICAL:
             raise ValueError(f"{mode} is not handled for now")
 
@@ -628,6 +628,10 @@ class SAAxisTask(
 
         saaxis_results_url = SAAxisTask.get_results_url(scan=scan)
 
+        if not os.path.exists(saaxis_results_url.file_path()):
+            _logger.error("no result saved")
+            return
+
         # save it to the file
         with HDF5File(saaxis_results_url.file_path(), mode="a") as h5f:
             nx_process = h5f.require_group(saaxis_results_url.data_path())
