@@ -1,5 +1,5 @@
 import os
-from silx.utils.enum import Enum as _Enum
+from enum import Enum as _Enum
 
 
 __LBSRAM_PATH = "/lbsram"
@@ -90,7 +90,7 @@ class SlurmSettingsMode(_Enum):
 class SlurmSettings:
     # Default slurm cluster configuration
 
-    N_CORES_PER_TASK = 4
+    N_CORES_PER_TASK = 16
     """Number of CPU per worker"""
 
     N_TASKS = 1
@@ -130,9 +130,9 @@ class DefaultSlurmSettingsCastVolume(SlurmSettings):
     default proposed configuration for casting a volume remotely
     """
 
-    N_GPUS_PER_WORKER = 0
+    N_JOBS = 1
 
-    N_CORES_PER_TASK = 8
+    N_GPUS_PER_WORKER = 0
 
     MEMORY_PER_WORKER = 128  # memory in GB
 
@@ -144,19 +144,15 @@ class DefaultSlurmSettingsSliceReconstruction(SlurmSettings):
     default proposed configuration for reconstructing a single slice remotely
     """
 
-    MEMORY_PER_WORKER = 256  # memory in GB
+    N_JOBS = 1
 
-    PARTITION = None
+    N_GPUS_PER_WORKER = 1
+
+    MEMORY_PER_WORKER = 220  # memory in GB
 
 
-class DefaultSlurmSettingsVolumeReconstruction(SlurmSettings):
-    """
-    default proposed configuration for reconstructing a full volume remotely
-    """
-
-    MEMORY_PER_WORKER = 256  # memory in GB
-
-    PARTITION = None
+class DefaultSlurmSettingsVolumeReconstruction(DefaultSlurmSettingsSliceReconstruction):
+    pass
 
 
 class DefaultSlurmSettingsStitching(SlurmSettings):
@@ -164,8 +160,10 @@ class DefaultSlurmSettingsStitching(SlurmSettings):
     default proposed configuration for stitching
     """
 
-    N_JOBS = 15
+    N_CORES_PER_TASK = 1
 
-    PARTITION = "nice-long"
+    N_JOBS = 16
 
     N_GPUS_PER_WORKER = 0
+
+    PARTITION = "nice-long"
