@@ -94,7 +94,7 @@ class SlurmSettingsWindow(qt.QMainWindow):
 
         self._modeCombox = qt.QComboBox(self)
         self._mainWidget.layout().addRow("configuration: ", self._modeCombox)
-        self._modeCombox.addItems(SlurmSettingsMode.values())
+        self._modeCombox.addItems([item.value for item in SlurmSettingsMode])
         self._modeCombox.setCurrentText(SlurmSettingsMode.GENERIC.value)
 
         self._settingsWidget = SlurmSettingsWidget(self, jobLimitation=None)
@@ -110,6 +110,7 @@ class SlurmSettingsWindow(qt.QMainWindow):
         # connect signal / slot
         self._modeCombox.currentIndexChanged.connect(self._reloadPredefinedSettings)
         self._settingsWidget.sigConfigChanged.connect(self._configChanged)
+        self._modeCombox.currentIndexChanged.connect(self.sigConfigChanged)
         # when the settings widget is edited them we automatically move to 'manual' settings. To notify visually the user
         self._settingsWidget.sigConfigChanged.connect(self._switchToManual)
 
@@ -154,12 +155,20 @@ class SlurmSettingsWindow(qt.QMainWindow):
         self._modeCombox.setCurrentText(SlurmSettingsMode.MANUAL.value)
 
     def getCurrentSettingsMode(self) -> SlurmSettingsMode:
-        return SlurmSettingsMode.from_value(self._modeCombox.currentText())
+        return SlurmSettingsMode(self._modeCombox.currentText())
 
     def setCurrentSettingsMode(self, mode: SlurmSettingsMode) -> SlurmSettingsMode:
-        mode = SlurmSettingsMode.from_value(mode)
+        mode = SlurmSettingsMode(mode)
         self._modeCombox.setCurrentText(mode.value)
 
+    def setMode(self, mode: SlurmSettingsMode) -> None:
+        """Alias for setCurrentSettingsMode(), used by SlurmClusterOW."""
+        self.setCurrentSettingsMode(mode)
+
+    def mode(self) -> SlurmSettingsMode:
+        """Alias for getCurrentSettingsMode(), used by SlurmClusterOW."""
+        return self.getCurrentSettingsMode()
+
     # expose API
     def getConfiguration(self) -> dict:
         return self._settingsWidget.getConfiguration()
