@@ -6,7 +6,7 @@ from typing import Iterable
 
 from silx.gui import qt
 from silx.gui.utils import blockSignals
-from silx.utils.enum import Enum as _Enum
+from enum import Enum as _Enum
 from tomoscan.series import Series
 
 from tomwer.core.scan.scanbase import TomwerScanBase
@@ -144,8 +144,8 @@ class SeriesDefinition(qt.QWidget):
         self.layout().addWidget(self._modeLabel, 0, 0, 1, 1)
 
         self._modeCB = qt.QComboBox(self)
-        for mode in _SeriesDefinitionMode.values():
-            self._modeCB.addItem(mode)
+        for mode in _SeriesDefinitionMode:
+            self._modeCB.addItem(mode.value)
         self.layout().addWidget(self._modeCB, 0, 1, 1, 1)
 
         self._manualDefWidget = SeriesManualFromTomoObj(parent=self)
@@ -169,10 +169,10 @@ class SeriesDefinition(qt.QWidget):
             raise ValueError(f"mode {self.getMode()} is not handled yet")
 
     def getMode(self) -> str:
-        return _SeriesDefinitionMode.from_value(self._modeCB.currentText())
+        return _SeriesDefinitionMode(self._modeCB.currentText())
 
     def setMode(self, mode: str):
-        mode = _SeriesDefinitionMode.from_value(mode)
+        mode = _SeriesDefinitionMode(mode)
         idx = self._modeCB.findText(mode.value)
         self._modeCB.setCurrentIndex(idx)
 
