@@ -112,9 +112,7 @@ class ImageKeyWindow(qt.QMainWindow):
     def setModifications(self, modifications):
         self._mainWindow.clearModifcations()
         image_keys_set = set(modifications.values())
-        image_keys_set = set(
-            [_ImageKey.from_value(image_key) for image_key in image_keys_set]
-        )
+        image_keys_set = set([_ImageKey(image_key) for image_key in image_keys_set])
         for image_key_type in image_keys_set:
             self._mainWindow.applyModifications(
                 modifications=modifications, new_image_key=image_key_type
@@ -432,7 +430,7 @@ class _ImageKeyList(qt.QTableWidget):
             self.setItem(i_frame, 0, _item)
 
             # current image key
-            current_image_key = _ImageKey.from_value(frame.image_key)
+            current_image_key = _ImageKey(frame.image_key)
             current_image_key = self._IMAGE_KEYS_INV[current_image_key]
             currentImgKeyItem = qt.QLabel(current_image_key, self)
             self.setCellWidget(i_frame, 1, currentImgKeyItem)
@@ -442,7 +440,7 @@ class _ImageKeyList(qt.QTableWidget):
                 new_image_key = frames_new_keys[frame.index]
             else:
                 new_image_key = frame.image_key
-            new_image_key = _ImageKey.from_value(new_image_key)
+            new_image_key = _ImageKey(new_image_key)
             new_image_key = self._IMAGE_KEYS_INV[new_image_key]
             newImgKeyItem = _ImageKeyComboBox(parent=self, image_key=new_image_key)
             self._imageKeyComboboxes[index] = newImgKeyItem
@@ -694,16 +692,16 @@ class ImageKeyUpgraderList(qt.QTableWidget):
             self.setCellWidget(i_operation, 1, remove_button)
 
     def addOperation(self, from_image_key: _ImageKey, to_image_key: _ImageKey):
-        from_image_key = _ImageKey.from_value(from_image_key)
-        to_image_key = _ImageKey.from_value(to_image_key)
+        from_image_key = _ImageKey(from_image_key)
+        to_image_key = _ImageKey(to_image_key)
 
         self._operations[from_image_key] = to_image_key
         self._update()
         self.sigOperationsChanged.emit()
 
     def removeOperation(self, from_image_key: _ImageKey, to_image_key: _ImageKey):
-        from_image_key = _ImageKey.from_value(from_image_key)
-        to_image_key = _ImageKey.from_value(to_image_key)
+        from_image_key = _ImageKey(from_image_key)
+        to_image_key = _ImageKey(to_image_key)
         if (
             from_image_key not in self._operations
             or self._operations[from_image_key] != to_image_key
