@@ -221,7 +221,7 @@ class _NabuPreProcessingConfig(_NabuStageConfigBase, qt.QWidget):
         self._signalConfChanged("flatfield")
 
     def _dffChanged(self, *args, **kwargs):
-        self._signalConfChanged("double_flatfield_enabled")
+        self._signalConfChanged("double_flatfield")
 
     def _dffSigmaChanged(self, *args, **kwargs):
         self._signalConfChanged("dff_sigma")
@@ -337,7 +337,7 @@ class _NabuPreProcessingConfig(_NabuStageConfigBase, qt.QWidget):
         tilt_correction, autotilt_opts = self._tiltCorrection.getTiltCorrection()
         return {
             "flatfield": int(self.isFlatFieldActivate()),
-            "double_flatfield_enabled": int(self.isDoubleFlatFieldActivate()),
+            "double_flatfield": int(self.isDoubleFlatFieldActivate()),
             "dff_sigma": self.getDFFSigma(),
             "ccd_filter_enabled": int(self.isCCDFilterActivate()),
             "ccd_filter_threshold": self.getCCDThreshold(),
@@ -365,7 +365,7 @@ class _NabuPreProcessingConfig(_NabuStageConfigBase, qt.QWidget):
         if ff is not None:
             self._flatFieldCB.setChecked(bool(ff))
 
-        dff = conf.get("double_flatfield_enabled", None)
+        dff = conf.get("double_flatfield", None)
         if dff is not None:
             self._dffCB.setChecked(bool(dff))
 
@@ -401,9 +401,7 @@ class _NabuPreProcessingConfig(_NabuStageConfigBase, qt.QWidget):
         if sino_rings_correction is not None:
             if sino_rings_correction == "":
                 sino_rings_correction = RingCorrectionMethod.NONE
-            sino_rings_correction = RingCorrectionMethod.from_value(
-                sino_rings_correction
-            ).value
+            sino_rings_correction = RingCorrectionMethod(sino_rings_correction).value
             idx = self._sinoRingCorrectionMthd.findText(sino_rings_correction)
             if idx >= 0:
                 self._sinoRingCorrectionMthd.setCurrentIndex(idx)
@@ -581,7 +579,7 @@ class SinoRingsOptions(qt.QWidget):
             self._sigmaHigh.setValue(float(high_pass))
 
     def setMethod(self, method: RingCorrectionMethod):
-        method = RingCorrectionMethod.from_value(method)
+        method = RingCorrectionMethod(method)
         self._method = method
         # handle munch options
         self._sigmaMunch.setVisible(method is RingCorrectionMethod.MUNCH)
