@@ -7,7 +7,7 @@ import logging
 
 from silx.gui import qt
 from silx.gui.dialog.DataFileDialog import DataFileDialog
-from silx.utils.enum import Enum as _Enum
+from enum import Enum as _Enum
 
 from nxtomomill.io.utils import convert_str_to_tuple
 from tomwer.core.utils.char import DEGREE_CHAR
@@ -97,7 +97,7 @@ class SliceGroupBox(qt.QGroupBox):
         )
 
     def setMode(self, mode: NabuSliceMode):
-        mode = NabuSliceMode.from_value(mode)
+        mode = NabuSliceMode(mode)
         item_index = self._modeCB.findText(mode.value)
         self._modeCB.setCurrentIndex(item_index)
         old = self.blockSignals(True)
@@ -105,7 +105,7 @@ class SliceGroupBox(qt.QGroupBox):
         self.blockSignals(old)
 
     def getMode(self) -> NabuSliceMode:
-        mode = NabuSliceMode.from_value(self._modeCB.currentText())
+        mode = NabuSliceMode(self._modeCB.currentText())
         return mode
 
     def _getSliceSelected(self):
@@ -159,9 +159,13 @@ class TranslationMvtFileWidget(qt.QWidget):
         self._grpBox.layout().setContentsMargins(0, 0, 0, 0)
         self._grpBox.layout().setSpacing(0)
 
-        self._hdf5FileRB = qt.QRadioButton(self.Mode.HDF5.value, self)
+        self._hdf5FileRB = qt.QRadioButton(
+            TranslationMvtFileWidget.Mode.HDF5.value, self
+        )
         self._grpBox.layout().addWidget(self._hdf5FileRB)
-        self._textFileRB = qt.QRadioButton(self.Mode.TEXT.value, self)
+        self._textFileRB = qt.QRadioButton(
+            TranslationMvtFileWidget.Mode.TEXT.value, self
+        )
         self._grpBox.layout().addWidget(self._textFileRB)
         self.layout().addWidget(self._grpBox)
 
@@ -334,45 +338,52 @@ class _NabuReconstructionConfig(qt.QWidget, _NabuStageConfigBase):
         self.registerWidget(self._methodLabel, "required")
         self.registerWidget(self._methodQCB, "required")
 
+        self._methodWarningLabel = qt.QLabel(
+            f"\tWARNING: \n\t1.' {_NabuReconstructionMethods.MLEM.value}' can be EXTREMELY SLOW on transmission\n\tdata and may produce erroneous results.\n\t2.MLEM should only be used with XRFCT data."
+        )
+        self._methodWarningLabel.setStyleSheet("color: red")
+        self._methodWarningLabel.setVisible(False)
+        self.layout().addWidget(self._methodWarningLabel, 3, 0, 1, 2)
+
         # angle_offset
         self._labelOffsetLabel = qt.QLabel("angle offset (in degree)", self)
-        self.layout().addWidget(self._labelOffsetLabel, 3, 0, 1, 1)
+        self.layout().addWidget(self._labelOffsetLabel, 4, 0, 1, 1)
         self._angleOffsetQDSB = QDoubleSpinBoxIgnoreWheel(self)
         self._angleOffsetQDSB.setMaximum(-180)
         self._angleOffsetQDSB.setMaximum(180)
-        self.layout().addWidget(self._angleOffsetQDSB, 3, 1, 1, 1)
+        self.layout().addWidget(self._angleOffsetQDSB, 4, 1, 1, 1)
         self.registerWidget(self._labelOffsetLabel, "advanced")
         self.registerWidget(self._angleOffsetQDSB, "advanced")
 
         # fbp filter type
         self._fbpFilterCB = qt.QCheckBox("fbp filter", self)
-        self.layout().addWidget(self._fbpFilterCB, 4, 0, 1, 1)
+        self.layout().addWidget(self._fbpFilterCB, 5, 0, 1, 1)
         self._fbpFilterType = QComboBoxIgnoreWheel(self)
         for filter_type in _NabuFBPFilterType:
             self._fbpFilterType.addItem(filter_type.value)
-        self.layout().addWidget(self._fbpFilterType, 4, 1, 1, 1)
+        self.layout().addWidget(self._fbpFilterType, 5, 1, 1, 1)
         self.registerWidget(self._fbpFilterCB, "advanced")
         self.registerWidget(self._fbpFilterType, "advanced")
 
         # padding type
         self._paddingTypeLabel = qt.QLabel("padding type", self)
-        self.layout().addWidget(self._paddingTypeLabel, 5, 0, 1, 1)
+        self.layout().addWidget(self._paddingTypeLabel, 6, 0, 1, 1)
         self._paddingType = QComboBoxIgnoreWheel(self)
         for fbp_padding_type in _NabuPaddingType:
             self._paddingType.addItem(fbp_padding_type.value)
-        self.layout().addWidget(self._paddingType, 5, 1, 1, 1)
+        self.layout().addWidget(self._paddingType, 6, 1, 1, 1)
         self.registerWidget(self._paddingTypeLabel, "optional")
         self.registerWidget(self._paddingType, "optional")
 
         # sub region
         self._subRegionSelector = _NabuReconstructionSubRegion(parent=self)
-        self.layout().addWidget(self._subRegionSelector, 7, 0, 1, 2)
+        self.layout().addWidget(self._subRegionSelector, 8, 0, 1, 2)
 
         # iterations
         self._iterationsLabel = qt.QLabel("iterations", self)
-        self.layout().addWidget(self._iterationsLabel, 8, 0, 1, 1)
+        self.layout().addWidget(self._iterationsLabel, 9, 0, 1, 1)
         self._iterationSB = qt.QSpinBox(parent=self)
-        self.layout().addWidget(self._iterationSB, 8, 1, 1, 1)
+        self.layout().addWidget(self._iterationSB, 9, 1, 1, 1)
         self._iterationSB.setMinimum(1)
         self._iterationSB.setMaximum(9999)
         # not supported for now so hidden
@@ -383,20 +394,20 @@ class _NabuReconstructionConfig(qt.QWidget, _NabuStageConfigBase):
         self._binSubSamplingGB = _BinSubSampling(
             "binning and sub-sampling", parent=self
         )
-        self.layout().addWidget(self._binSubSamplingGB, 9, 0, 1, 2)
+        self.layout().addWidget(self._binSubSamplingGB, 10, 0, 1, 2)
 
         # optimization algorithm:
         # set has default value for now, because has only one at the moment
 
         # weight total variation
         self._tvLabel = qt.QLabel("total variation weight", self)
-        self.layout().addWidget(self._tvLabel, 10, 0, 1, 1)
+        self.layout().addWidget(self._tvLabel, 11, 0, 1, 1)
         self._totalVariationWeight = qt.QDoubleSpinBox(self)
         self._totalVariationWeight.setMinimum(0.0)
         self._totalVariationWeight.setMaximum(1.0)
         self._totalVariationWeight.setDecimals(4)
         self._totalVariationWeight.setSingleStep(0.002)
-        self.layout().addWidget(self._totalVariationWeight, 9, 1, 1, 1)
+        self.layout().addWidget(self._totalVariationWeight, 10, 1, 1, 1)
         # not supported for now so hidden
         self._tvLabel.hide()
         self._totalVariationWeight.hide()
@@ -406,7 +417,7 @@ class _NabuReconstructionConfig(qt.QWidget, _NabuStageConfigBase):
         self._preconditioningFilter.setToolTip(
             'Whether to enable "filter ' 'preconditioning" for iterative' " methods"
         )
-        self.layout().addWidget(self._preconditioningFilter, 10, 0, 1, 2)
+        self.layout().addWidget(self._preconditioningFilter, 11, 0, 1, 2)
         # not supported for now so hidden
         self._preconditioningFilter.hide()
 
@@ -415,7 +426,7 @@ class _NabuReconstructionConfig(qt.QWidget, _NabuStageConfigBase):
         self._positivityConstraintCB.setToolTip(
             "Whether to enforce a " "positivity constraint in the " "reconstruction."
         )
-        self.layout().addWidget(self._positivityConstraintCB, 11, 0, 1, 2)
+        self.layout().addWidget(self._positivityConstraintCB, 12, 0, 1, 2)
         # not supported for now so hidden
         self._positivityConstraintCB.hide()
 
@@ -424,13 +435,13 @@ class _NabuReconstructionConfig(qt.QWidget, _NabuStageConfigBase):
         self._clipOuterCircleCB.setToolTip(
             "Whether to set to zero voxels falling outside of the reconstruction region"
         )
-        self.layout().addWidget(self._clipOuterCircleCB, 12, 0, 1, 2)
+        self.layout().addWidget(self._clipOuterCircleCB, 13, 0, 1, 2)
         self.registerWidget(self._clipOuterCircleCB, "optional")
 
         # centered axis option
         self._centeredAxisCB = qt.QCheckBox("centered axis", self)
         self._centeredAxisCB.setToolTip("")
-        self.layout().addWidget(self._centeredAxisCB, 13, 0, 1, 2)
+        self.layout().addWidget(self._centeredAxisCB, 14, 0, 1, 2)
         self.registerWidget(self._centeredAxisCB, "optional")
 
         # translation movement file
@@ -440,6 +451,12 @@ class _NabuReconstructionConfig(qt.QWidget, _NabuStageConfigBase):
         self.layout().addWidget(self._transMvtFileWidget, 22, 1, 1, 1)
         self.registerWidget(self._transMvtFileLabel, "advanced")
         self.registerWidget(self._transMvtFileWidget, "advanced")
+        translation_movement_tooltip = """
+        A file where each line describes the horizontal and vertical translations of the sample (or detector).
+        The order is 'horizontal, vertical'
+        It can be created from a numpy array saved with 'numpy.savetxt'"""
+        self._transMvtFileLabel.setToolTip(translation_movement_tooltip)
+        self._transMvtFileWidget.setToolTip(translation_movement_tooltip)
 
         # angle files (if the user want's to overwrite rotation angles)
         self._angleFileLabel = qt.QLabel("angles file", self)
@@ -527,8 +544,12 @@ class _NabuReconstructionConfig(qt.QWidget, _NabuStageConfigBase):
     def _slicesChanged(self, *args, **kwargs):
         self._signalConfChanged("tomwer_slices")
 
-    def _methodChanged(self, *args, **kwargs):
+    def _methodChanged(self, index):  # *args, **kwargs):
         self._signalConfChanged("method")
+        selected_method = self.getMethod()
+        self._methodWarningLabel.setVisible(
+            selected_method == _NabuReconstructionMethods.MLEM
+        )
 
     def _angleOffsetChanged(self, *args, **kwargs):
         self._signalConfChanged("angle_offset")
@@ -574,10 +595,10 @@ class _NabuReconstructionConfig(qt.QWidget, _NabuStageConfigBase):
         raise NotImplementedError()
 
     def getMethod(self) -> _NabuReconstructionMethods:
-        return _NabuReconstructionMethods.from_value(self._methodQCB.currentText())
+        return _NabuReconstructionMethods(self._methodQCB.currentText())
 
     def setMethod(self, method):
-        method = _NabuReconstructionMethods.from_value(method)
+        method = _NabuReconstructionMethods(method)
         item_index = self._methodQCB.findText(method.value)
         self._methodQCB.setCurrentIndex(item_index)
 
@@ -589,7 +610,7 @@ class _NabuReconstructionConfig(qt.QWidget, _NabuStageConfigBase):
 
     def getFBPFilterType(self) -> _NabuFBPFilterType | None:
         if self._fbpFilterCB.isChecked():
-            return _NabuFBPFilterType.from_value(self._fbpFilterType.currentText())
+            return _NabuFBPFilterType(self._fbpFilterType.currentText())
         else:
             return None
 
@@ -605,10 +626,10 @@ class _NabuReconstructionConfig(qt.QWidget, _NabuStageConfigBase):
             self._fbpFilterType.setCurrentIndex(filter_index)
 
     def getFBPPaddingType(self) -> _NabuPaddingType:
-        return _NabuPaddingType.from_value(self._paddingType.currentText())
+        return _NabuPaddingType(self._paddingType.currentText())
 
     def setFBPPaddingType(self, padding):
-        padding = _NabuPaddingType.from_value(padding)
+        padding = _NabuPaddingType(padding)
         padding_index = self._paddingType.findText(padding.value)
         self._paddingType.setCurrentIndex(padding_index)
 
@@ -1012,17 +1033,22 @@ class _BinSubSampling(qt.QGroupBox):
     def __init__(self, text, parent):
         qt.QGroupBox.__init__(self, text)
         self.setLayout(qt.QFormLayout())
-        # horizontal binning
-        self._hBinningSB = QSpinBoxIgnoreWheel(self)
-        self._hBinningSB.setMinimum(1)
-        self._hBinningSB.setMaximum(3)
-        self.layout().addRow("horizontal binning", self._hBinningSB)
-        # vertical binning
-        self._vBinningSB = qt.QSpinBox(self)
-        self._vBinningSB.setMinimum(1)
-        self._vBinningSB.setMaximum(100)
-        # self.layout().addRow('vertical binning', self._vBinningSB)
-        self._vBinningSB.setVisible(False)
+        # binning
+        self._binningSB = QSpinBoxIgnoreWheel(self)
+        self._binningSB.setMinimum(1)
+        self._binningSB.setMaximum(3)
+        self.layout().addRow("binning", self._binningSB)
+        self._binningSB.setToolTip(
+            "Binning factor in the horizontal dimension when reading the data. \nThe final slices dimensions will be divided by this factor."
+        )
+        # z binning
+        self._zBinningSB = qt.QSpinBox(self)
+        self._zBinningSB.setMinimum(1)
+        self._zBinningSB.setMaximum(100)
+        self.layout().addRow("vertical binning", self._zBinningSB)
+        self._zBinningSB.setToolTip(
+            "Binning factor in the vertical dimension when reading the data. \nThis results in a lesser number of reconstructed slices."
+        )
         # projection sub-sampling
         self._projSubsamplingSB = QSpinBoxIgnoreWheel(self)
         self._projSubsamplingSB.setMinimum(1)
@@ -1030,35 +1056,35 @@ class _BinSubSampling(qt.QGroupBox):
         self.layout().addRow("projection sub-sampling", self._projSubsamplingSB)
 
         # connect signal / slot
-        self._vBinningSB.valueChanged.connect(self._valueUpdated)
-        self._hBinningSB.valueChanged.connect(self._valueUpdated)
+        self._zBinningSB.valueChanged.connect(self._valueUpdated)
+        self._binningSB.valueChanged.connect(self._valueUpdated)
 
-    def getHorizontalBinning(self):
-        return self._hBinningSB.value()
+    def getHorizontalBinning(self) -> int:
+        return self._binningSB.value()
 
-    def setHorizontalBinning(self, binning):
-        return self._hBinningSB.setValue(int(binning))
+    def setHorizontalBinning(self, binning: int):
+        return self._binningSB.setValue(int(binning))
 
-    def getVerticalBinning(self):
-        return self._vBinningSB.value()
+    def getVerticalBinning(self) -> int:
+        return self._zBinningSB.value()
 
-    def setVerticalBinning(self, binning):
-        return self._vBinningSB.setValue(int(binning))
+    def setVerticalBinning(self, binning: int):
+        return self._zBinningSB.setValue(int(binning))
 
-    def getProjSubsampling(self):
+    def getProjSubsampling(self) -> int:
         return self._projSubsamplingSB.value()
 
-    def setProjSubsampling(self, subsampling):
+    def setProjSubsampling(self, subsampling: int):
         return self._projSubsamplingSB.setValue(int(subsampling))
 
-    def getConfiguration(self):
+    def getConfiguration(self) -> dict:
         return {
             "binning": self.getHorizontalBinning(),
             "binning_z": self.getVerticalBinning(),
             "projections_subsampling": self.getProjSubsampling(),
         }
 
-    def setConfiguration(self, config):
+    def setConfiguration(self, config: dict):
         if "binning" in config:
             self.setHorizontalBinning(config["binning"])
         if "binning_z" in config:
