@@ -493,21 +493,21 @@ class _NormIntensityOptions(qt.QWidget):
         self._lockButton.hide()
 
     def getCurrentMethod(self):
-        return Method.from_value(self._modeCB.currentText())
+        return Method(self._modeCB.currentText())
 
     def setCurrentMethod(self, method):
-        method = Method.from_value(method)
+        method = Method(method)
         idx = self._modeCB.findText(method.value)
         self._modeCB.setCurrentIndex(idx)
 
     def getCurrentSource(self):
         if self.getCurrentMethod() in (Method.DIVISION, Method.SUBTRACTION):
-            return _ValueSource.from_value(self._sourceCB.currentText())
+            return _ValueSource(self._sourceCB.currentText())
         else:
             return _ValueSource.NONE
 
     def setCurrentSource(self, source):
-        source = _ValueSource.from_value(source)
+        source = _ValueSource(source)
         idx = self._sourceCB.findText(source.value)
         self._sourceCB.setCurrentIndex(idx)
 
@@ -601,8 +601,8 @@ class _NormIntensityCalcOpts(qt.QWidget):
         self.setLayout(qt.QFormLayout())
         # calculation function
         self._calculationModeCB = qt.QComboBox(self)
-        for fct in _normParams._ValueCalculationFct.values():
-            self._calculationModeCB.addItem(fct)
+        for fct in _normParams._ValueCalculationFct:
+            self._calculationModeCB.addItem(fct.value)
         self._calculationModeLabel = qt.QLabel("calculation fct", self)
         self.layout().addRow(self._calculationModeLabel, self._calculationModeCB)
 
@@ -616,14 +616,10 @@ class _NormIntensityCalcOpts(qt.QWidget):
         self._calculationModeCB.setVisible(visible)
 
     def getCalculationFct(self):
-        return _normParams._ValueCalculationFct.from_value(
-            self._calculationModeCB.currentText()
-        )
+        return _normParams._ValueCalculationFct(self._calculationModeCB.currentText())
 
     def setCalculationFct(self, fct):
-        idx = self._calculationModeCB.findText(
-            _normParams._ValueCalculationFct.from_value(fct)
-        )
+        idx = self._calculationModeCB.findText(_normParams._ValueCalculationFct(fct))
         self._calculationModeCB.setCurrentIndex(idx)
 
 
