@@ -272,7 +272,7 @@ class StitchingOptionsWidget(qt.QWidget):
             self._normalizationBySampleWidget.setConfiguration(normalization_by_sample)
 
     def _stitchingTypeChanged(self, stitching_type: str):
-        stitching_type = StitchingType.from_value(stitching_type)
+        stitching_type = StitchingType(stitching_type)
         self._alignmentGroup.setAlignmentAxis1Enabled(
             stitching_type is StitchingType.Z_POSTPROC
         )
