@@ -4,7 +4,7 @@ from __future__ import annotations
 import functools
 import numpy
 from silx.gui import qt
-from silx.utils.enum import Enum as _Enum
+from enum import Enum as _Enum
 
 from tomwer.core.tomwer_object import TomwerObject
 from tomwer.gui import icons
@@ -333,9 +333,15 @@ class _TomoObjPosition(qt.QWidget):
         self.layout().addWidget(self._resetValueQPB)
 
         # connect signal / slot
-        self._spinBox.valueChanged.connect(self._valueChanged)
+        self._spinBox.editingFinished.connect(self._sbEditingFinished)
         self._resetValueQPB.clicked.connect(self.resetOriginalValue)
 
+    def _sbEditingFinished(self):
+        sender = self.sender()
+        assert isinstance(sender, qt.QSpinBox)
+        new_value = sender.value()
+        self._valueChanged(new_value=new_value)
+
     def _valueChanged(self, new_value):
         self.sigValueChanged.emit(
             self.__lastValue,
@@ -354,10 +360,12 @@ class _TomoObjPosition(qt.QWidget):
         self._positionChanged()
 
     def _positionChanged(self):
-        self._valueChanged(new_value=self._spinBox.value())
+        self._valueChanged(self._spinBox.value())
 
-    def setValue(self, value: float) -> None:
+    def setValue(self, value: float, emit_editing_finished: bool = False) -> None:
         self._spinBox.setValue(value)
+        if emit_editing_finished:
+            self._spinBox.editingFinished.emit()
         self.__lastValue = value
 
     def getValue(self) -> float:
