@@ -4,6 +4,7 @@ Button of general usage.
 
 from __future__ import annotations
 
+import pint
 import numpy
 import logging
 from silx.gui import qt
@@ -12,11 +13,11 @@ from silx.gui.plot.items.roi import LineROI
 from silx.gui.plot.PlotToolButtons import PlotToolButton
 
 from tomwer.gui import icons
-from pyunitsystem.metricsystem import MetricSystem
-
 
 _logger = logging.getLogger(__file__)
 
+_ureg = pint.get_application_registry()
+
 
 class PadlockButton(qt.QPushButton):
     """Simple button to define a button with PadLock icons"""
@@ -87,40 +88,11 @@ class TabBrowsersButtons(qt.QWidget):
 class TapeMeasureToolButton(PlotToolButton):
     """Button to active measurement between two point of the plot"""
 
-    class TapeMeasureROI(LineROI):
-        def __init__(self, parent=None, pixel_size_m=None):
-            super().__init__(parent)
-            self._pixel_size_m = None
-            self.setPixelSize(pixel_size_m)
-
-        def setEndPoints(self, startPoint, endPoint):
-            distance_px = numpy.linalg.norm(endPoint - startPoint)
-            super().setEndPoints(startPoint=startPoint, endPoint=endPoint)
-            if self._pixel_size_m is None:
-                self._updateText(f"{distance_px :.1f}px")
-            else:
-                distance_m = distance_px * self._pixel_size_m
-                value, unit = MetricSystem.cast_metric_to_best_unit(distance_m)
-                self._updateText(f"{distance_px :.1f}px ({value:.2f}{unit})")
-
-        def setPixelSize(self, pixel_size_m: tuple | float | None):
-            if isinstance(pixel_size_m, (tuple, list)):
-                assert (
-                    len(pixel_size_m) == 2
-                ), "expects at most two pixel size values (x and y values)"
-                if not numpy.isclose(pixel_size_m[0], pixel_size_m[1]):
-                    value, unit = MetricSystem.cast_metric_to_best_unit(pixel_size_m[0])
-                    _logger.warning(
-                        f"TapeMeasure is only handling square pixels for now. Will consider the pixel is {value:.2f}{unit}x{value:.2f}{unit}"
-                    )
-                pixel_size_m = pixel_size_m[0]
-            self._pixel_size_m = pixel_size_m
-
     def __init__(self, parent=None, plot=None, pixel_size_mm=None):
         super().__init__(parent=parent, plot=plot)
         self._roiManager = None
         self._lastRoiCreated = None
-        self._pixel_sixel_m = pixel_size_mm
+        self._pixel_size_m = pixel_size_mm
         self.setIcon(icons.getQIcon("ruler"))
         self.setToolTip("measure distance between two pixels")
         self.toggled.connect(self._callback)
@@ -130,7 +102,7 @@ class TapeMeasureToolButton(PlotToolButton):
         return super().setPlot(plot)
 
     def setPixelSize(self, pixel_size_m: tuple | float | None):
-        self._pixel_sixel_m = pixel_size_m
+        self._pixel_size_m = pixel_size_m
 
     def _callback(self, toggled):
         if not self._roiManager:
@@ -139,7 +111,7 @@ class TapeMeasureToolButton(PlotToolButton):
             self._lastRoiCreated.setVisible(self.isChecked())
         if self.isChecked():
             self._roiManager.start(
-                self.TapeMeasureROI,
+                TapeMeasureROI,
                 self,
             )
             self.__interactiveModeStarted(self._roiManager)
@@ -179,8 +151,54 @@ class TapeMeasureToolButton(PlotToolButton):
     def _registerCurrentROI(self, currentRoi):
         if self._lastRoiCreated is None:
             self._lastRoiCreated = currentRoi
-            self._lastRoiCreated.setPixelSize(self._pixel_sixel_m)
+            self._lastRoiCreated.setPixelSize(self._pixel_size_m)
         elif currentRoi != self._lastRoiCreated and self._roiManager is not None:
             self._roiManager.removeRoi(self._lastRoiCreated)
             self._lastRoiCreated = currentRoi
-            self._lastRoiCreated.setPixelSize(self._pixel_sixel_m)
+            self._lastRoiCreated.setPixelSize(self._pixel_size_m)
+
+
+class TapeMeasureROI(LineROI):
+    """ROI dedicated to tape measure"""
+
+    def __init__(self, parent=None, pixel_size_m=None):
+        super().__init__(parent)
+        self._pixel_size_m = None
+        self.setPixelSize(pixel_size_m)
+
+    def setEndPoints(self, startPoint, endPoint):
+        distance_px = numpy.linalg.norm(endPoint - startPoint)
+        super().setEndPoints(startPoint=startPoint, endPoint=endPoint)
+        if self._pixel_size_m is None:
+            self._updateText(f"{distance_px :.1f}px")
+        else:
+            distance_m = distance_px * self._pixel_size_m
+            value = self.cast_metric_to_best_unit(distance_m)
+            self._updateText(f"{distance_px :.1f}px ({value:~})")
+
+    def setPixelSize(self, pixel_size_m: tuple | float | None):
+        if isinstance(pixel_size_m, (tuple, list)):
+            assert (
+                len(pixel_size_m) == 2
+            ), "expects at most two pixel size values (x and y values)"
+            if not numpy.isclose(pixel_size_m[0], pixel_size_m[1]):
+                value = self.cast_metric_to_best_unit(pixel_size_m[0])
+                _logger.warning(
+                    f"TapeMeasure is only handling square pixels for now. Will consider the pixel is {value:~}{value:~}"
+                )
+            pixel_size_m = pixel_size_m[0]
+        self._pixel_size_m = pixel_size_m
+
+    @staticmethod
+    def cast_metric_to_best_unit(value: pint.Quantity) -> pint.Quantity:
+        value = value.to_base_units()
+        if value < (1.0 * _ureg.micrometer):
+            return value.to(_ureg.nanometer)
+        elif value < (0.1 * _ureg.millimeter):  # prefer mm to um
+            return value.to(_ureg.micrometer)
+        elif value < (1.0 * _ureg.centimeter):
+            return value.to(_ureg.millimeter)
+        elif value < (1.0 * _ureg.meter):
+            return value.to(_ureg.centimeter)
+        else:
+            return value.to(_ureg.meter)
