@@ -7,13 +7,13 @@ from __future__ import annotations
 import functools
 import logging
 import os
+from enum import Enum
 
 import numpy
 from processview.core.dataset import DatasetIdentifier
 from silx.gui import icons as silx_icons
 from silx.gui import qt
 from silx.io.url import DataUrl
-from silx.utils.enum import Enum as _Enum
 
 from tomwer.core.scan.nxtomoscan import NXtomoScan
 from tomwer.core.scan.scanbase import TomwerScanBase
@@ -55,7 +55,7 @@ class _FrameSelector(qt.QWidget):
     sigSelectedUrlChanged = qt.Signal()
     """signal emitted when the selected url changed"""
 
-    class FrameType(_Enum):
+    class FrameType(Enum):
         DARKS = "darks"
         FLATS = "flats"
         PROJ = "projections"
@@ -110,10 +110,10 @@ class _FrameSelector(qt.QWidget):
             return None
 
     def getTypeSelected(self):
-        return self.FrameType.from_value(self._frameTypeCB.currentText())
+        return self.FrameType(self._frameTypeCB.currentText())
 
     def _typeChanged(self, *args, **kwargs):
-        type_selected = self.FrameType.from_value(self.getTypeSelected())
+        type_selected = self.FrameType(self.getTypeSelected())
         self._proj_normalized.setVisible(
             type_selected in (self.FrameType.PROJ, self.FrameType.ALIGN_PROJ)
         )
